@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # 
-# Copyright 2004-2006 Zuza Software Foundation
+# Copyright 2004-2007 Zuza Software Foundation
 # 
 # This file is part of translate.
 #
@@ -22,26 +22,22 @@
 from Pootle import pagelayout
 from Pootle import projects
 from Pootle import pootlefile
-from Pootle import versioncontrol
+from translate.storage import versioncontrol
 # Versioning information
 from Pootle import __version__ as pootleversion
 from translate import __version__ as toolkitversion
 from jToolkit import __version__ as jtoolkitversion
 from kid import __version__ as kidversion
-from elementtree import ElementTree
+try:
+  # ElementTree is part of Python 2.5, so let's try that first
+  from xml.etree import ElementTree
+except ImportError:
+  from elementtree import ElementTree
 import os
 import sys
 import re
 import locale
 
-def summarizestats(statslist, totalstats=None):
-  if totalstats is None:
-    totalstats = {}
-  for statsdict in statslist:
-    for name, count in statsdict.iteritems():
-      totalstats[name] = totalstats.get(name, 0) + count
-  return totalstats
-
 def shortdescription(descr):
   """Returns a short description by removing markup and only including up 
   to the first br-tag"""
@@ -88,6 +84,7 @@ class PootleIndex(pagelayout.PootlePage):
     self.localize = session.localize
     self.nlocalize = session.nlocalize
     self.tr_lang = session.tr_lang
+    self.listseperator = session.lang.listseperator
     templatename = "index"
     description = getattr(session.instance, "description")
     meta_description = shortdescription(description)
@@ -98,8 +95,10 @@ class PootleIndex(pagelayout.PootlePage):
     instancetitle = getattr(session.instance, "title", session.localize("Pootle Demo"))
     pagetitle = instancetitle
     sessionvars = {"status": session.status, "isopen": session.isopen, "issiteadmin": session.issiteadmin()}
-    languages = [{"code": code, "name": self.tr_lang(name), "sep": ", "} for code, name in self.potree.getlanguages()]
-    languages.sort(cmp=locale.strcoll, key=lambda dict: dict["name"])
+    languages = [{"code": code, "name": self.tr_lang(name), "sep": self.listseperator} for code, name in self.potree.getlanguages()]
+    # rewritten for compatibility with Python 2.3
+    # languages.sort(cmp=locale.strcoll, key=lambda dict: dict["name"])
+    languages.sort(lambda x,y: locale.strcoll(x["name"], y["name"]))
     if languages:
       languages[-1]["sep"] = ""
     templatevars = {"pagetitle": pagetitle, "description": description, 
@@ -115,7 +114,7 @@ class PootleIndex(pagelayout.PootlePage):
     for projectcode in self.potree.getprojectcodes():
       projectname = self.potree.getprojectname(projectcode)
       description = shortdescription(self.potree.getprojectdescription(projectcode))
-      projects.append({"code": projectcode, "name": projectname, "description": description, "sep": ", "})
+      projects.append({"code": projectcode, "name": projectname, "description": description, "sep": self.listseperator})
     if projects:
       projects[-1]["sep"] = ""
     return projects
@@ -167,7 +166,9 @@ class UserIndex(pagelayout.PootlePage):
       if langlinks:
         langlinks[-1]["sep"] = ""
       quicklinks.append({"code": languagecode, "name": self.tr_lang(languagename), "projects": langlinks})
-      quicklinks.sort(cmp=locale.strcoll, key=lambda dict: dict["name"])
+      # rewritten for compatibility with Python 2.3
+      # quicklinks.sort(cmp=locale.strcoll, key=lambda dict: dict["name"])
+      quicklinks.sort(lambda x,y: locale.strcoll(x["name"], y["name"]))
     return quicklinks
 
 class ProjectsIndex(PootleIndex):
@@ -210,7 +211,7 @@ class LanguageIndex(pagelayout.PootleNavPage):
         "projects": languageprojects, 
         "statsheadings": self.getstatsheadings(),
         "session": sessionvars, "instancetitle": instancetitle}
-    pagelayout.PootleNavPage.__init__(self, templatename, templatevars, session, bannerheight=81)
+    pagelayout.PootleNavPage.__init__(self, templatename, templatevars, session, bannerheight=80)
 
   def getlanguageinfo(self):
     """returns information defined for the language"""
@@ -241,8 +242,8 @@ class LanguageIndex(pagelayout.PootleNavPage):
     project = self.potree.getproject(self.languagecode, projectcode)
     pofilenames = project.browsefiles()
     projectstats = project.getquickstats()
-    projectdata = self.getstats(project, projectstats, len(pofilenames))
-    self.updatepagestats(projectdata["translatedwords"], projectdata["totalwords"])
+    projectdata = self.getstats(project, projectstats)
+    self.updatepagestats(projectdata["translatedsourcewords"], projectdata["totalsourcewords"])
     return {"code": projectcode, "href": href, "icon": "folder", "title": projectname, "description": projectdescription, "data": projectdata, "isproject": True}
 
 class ProjectLanguageIndex(pagelayout.PootleNavPage):
@@ -276,14 +277,16 @@ class ProjectLanguageIndex(pagelayout.PootleNavPage):
         "adminlink": adminlink, "languages": languages,
         "session": sessionvars, "instancetitle": instancetitle, 
         "statsheadings": statsheadings}
-    pagelayout.PootleNavPage.__init__(self, templatename, templatevars, session, bannerheight=81)
+    pagelayout.PootleNavPage.__init__(self, templatename, templatevars, session, bannerheight=80)
 
   def getlanguages(self):
     """gets the stats etc of the languages"""
     languages = self.potree.getlanguages(self.projectcode)
     self.languagecount = len(languages)
     languageitems = [self.getlanguageitem(languagecode, languagename) for languagecode, languagename in languages]
-    languageitems.sort(cmp=locale.strcoll, key=lambda dict: dict["title"])
+    # rewritten for compatibility with Python 2.3
+    # languageitems.sort(cmp=locale.strcoll, key=lambda dict: dict["title"])
+    languageitems.sort(lambda x,y: locale.strcoll(x["title"], y["title"]))
     for n, item in enumerate(languageitems):
       item["parity"] = ["even", "odd"][n % 2]
     return languageitems
@@ -292,8 +295,8 @@ class ProjectLanguageIndex(pagelayout.PootleNavPage):
     language = self.potree.getproject(languagecode, self.projectcode)
     href = "../../%s/%s/" % (languagecode, self.projectcode)
     quickstats = language.getquickstats()
-    data = self.getstats(language, quickstats, len(language.pofilenames))
-    self.updatepagestats(data["translatedwords"], data["totalwords"])
+    data = self.getstats(language, quickstats)
+    self.updatepagestats(data["translatedsourcewords"], data["totalsourcewords"])
     return {"code": languagecode, "icon": "language", "href": href, "title": self.tr_lang(languagename), "data": data}
 
 class ProjectIndex(pagelayout.PootleNavPage):
@@ -310,7 +313,7 @@ class ProjectIndex(pagelayout.PootleNavPage):
       dirfilter = None
     self.dirfilter = dirfilter
     if dirfilter and dirfilter.endswith(".po"):
-      self.dirname = "/".join(dirfilter.split("/")[:-1])
+      self.dirname = os.path.dirname(dirfilter)
     else:
       self.dirname = dirfilter or ""
     self.argdict = argdict
@@ -342,7 +345,7 @@ class ProjectIndex(pagelayout.PootleNavPage):
       else: 
         actionlinks = self.getactionlinks("", projectstats, ["editing", "goal", "zip", "sdf"])
       mainstats = self.getitemstats("", projectstats, len(pofilenames))
-      maindata = self.getstats(self.project, projectstats, len(pofilenames))
+      maindata = self.getstats(self.project, projectstats)
       mainicon = "folder"
     if self.showgoals:
       childitems = self.getgoalitems(dirfilter)
@@ -369,13 +372,13 @@ class ProjectIndex(pagelayout.PootleNavPage):
         "statsheadings": self.getstatsheadings(), 
         # general vars
         "session": sessionvars, "instancetitle": instancetitle}
-    pagelayout.PootleNavPage.__init__(self, templatename, templatevars, session, bannerheight=81)
+    pagelayout.PootleNavPage.__init__(self, templatename, templatevars, session, bannerheight=80)
     if self.showassigns and "assign" in self.rights:
       self.templatevars["assign"] = self.getassignbox()
     if "admin" in self.rights:
       if self.showgoals:
         self.templatevars["goals"] = self.getgoalbox()
-    if "admin" in self.rights or "translate" in self.rights:
+    if "admin" in self.rights or "translate" in self.rights or "suggest" in self.rights:
       self.templatevars["upload"] = self.getuploadbox()
 
   def handleactions(self):
@@ -612,7 +615,7 @@ class ProjectIndex(pagelayout.PootleNavPage):
     goalchildren = {}
     allchildren = []
     for childname in self.project.browsefiles(dirfilter=dirfilter, depth=depth, includedirs=True, includefiles=False):
-      allchildren.append(childname+"/")
+      allchildren.append(childname + os.path.sep)
     for childname in self.project.browsefiles(dirfilter=dirfilter, depth=depth, includedirs=False, includefiles=True):
       allchildren.append(childname)
     initial = dirfilter
@@ -681,7 +684,7 @@ class ProjectIndex(pagelayout.PootleNavPage):
         goal["goal"]["otherusers"] = unassignedusers
         goal["goal"]["adduser_title"] = self.localize("Add User")
     goal["stats"] = self.getitemstats("", projectstats, len(pofilenames))
-    goal["data"] = self.getstats(self.project, projectstats, len(pofilenames))
+    goal["data"] = self.getstats(self.project, projectstats)
     return goal
 
   def getdiritem(self, direntry, linksrequired=None, **newargs):
@@ -700,10 +703,10 @@ class ProjectIndex(pagelayout.PootleNavPage):
     diritem["actions"] = actionlinks
     if self.showgoals and "goal" in self.argdict:
       diritem["stats"] = self.getitemstats(basename, projectstats, (len(goalfilenames), len(pofilenames)))
-      diritem["data"] = self.getstats(self.projects, projectstats, (len(goalfilenames), len(pofilenames)))
+      diritem["data"] = self.getstats(self.projects, projectstats)
     else:
       diritem["stats"] = self.getitemstats(basename, projectstats, len(pofilenames))
-      diritem["data"] = self.getstats(self.project, projectstats, len(pofilenames))
+      diritem["data"] = self.getstats(self.project, projectstats)
     return diritem
 
   def getfileitem(self, fileentry, linksrequired=None, **newargs):
@@ -741,12 +744,14 @@ class ProjectIndex(pagelayout.PootleNavPage):
         molink = {"href": moname, "text": self.localize('MO file')}
         actionlinks.append(molink)
     if "update" in linksrequired and "admin" in self.rights:
-      if versioncontrol.hasversioning(os.path.join(self.project.podir, self.dirname)):
+      if versioncontrol.hasversioning(os.path.join(self.project.podir,
+              self.dirname, basename)):
         # l10n: Update from version control (like CVS or Subversion)
         updatelink = {"href": "index.html?editing=1&doupdate=1&updatefile=%s" % (basename), "text": self.localize('Update')}
         actionlinks.append(updatelink)
     if "commit" in linksrequired and "commit" in self.rights:
-      if versioncontrol.hasversioning(os.path.join(self.project.podir, self.dirname)):
+      if versioncontrol.hasversioning(os.path.join(self.project.podir,
+              self.dirname, basename)):
         # l10n: Commit to version control (like CVS or Subversion)
         commitlink = {"href": "index.html?editing=1&docommit=1&commitfile=%s" % (basename), "text": self.localize('Commit')}
         actionlinks.append(commitlink)
@@ -758,7 +763,7 @@ class ProjectIndex(pagelayout.PootleNavPage):
         actionlink["sep"] = ""
     fileitem["actions"] = actions
     fileitem["stats"] = self.getitemstats(basename, projectstats, None)
-    fileitem["data"] = self.getstats(self.project, projectstats, None)
+    fileitem["data"] = self.getstats(self.project, projectstats)
     return fileitem
 
   def getgoalform(self, basename, goalfile, filegoals):
@@ -890,12 +895,12 @@ class ProjectIndex(pagelayout.PootleNavPage):
       actionlinks.append(translatelink)
     if "zip" in linksrequired and "archive" in self.rights:
       if filepath and filepath.endswith(".po"):
-        currentfolder = "/".join(filepath.split("/")[:-1])
+        currentfolder = os.path.dirname(filepath)
       else:
         currentfolder = filepath
       archivename = "%s-%s" % (self.project.projectcode, self.project.languagecode)
       if currentfolder:
-        archivename += "-%s" % currentfolder.replace("/", "-")
+        archivename += "-%s" % currentfolder.replace(os.path.sep, "-")
       if goal:
         archivename += "-%s" % goal
       archivename += ".zip"
