@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # 
-# Copyright 2004-2006 Zuza Software Foundation
+# Copyright 2004-2007 Zuza Software Foundation
 # 
 # This file is part of translate.
 #
@@ -19,19 +19,7 @@
 # along with translate; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-def layout_banner(maxheight, session):
-  """calculates dimensions, image name for banner"""
-  logo_width, logo_height = min((98*maxheight/130, maxheight), (98, 130))
-  banner_width, banner_height = min((290*maxheight/160, maxheight), (290, 160))
-
-  if logo_width <= 61:
-    logo_image = getattr(getattr(session.instance, "logos", None), "medium", "/images/pootle-medium.png")
-  else:
-    logo_image = getattr(getattr(session.instance, "logos", None), "normal", "/images/pootle.png")
-  banner_image = getattr(getattr(session.instance, "logos", None), "banner", "/images/WordForge-white.png")
-  return {"logo_width": logo_width, "logo_height": logo_height,
-    "banner_width": banner_width, "banner_height": banner_height,
-    "logo_image": logo_image, "banner_image": banner_image}
+import os
 
 def localize_links(session):
   """Localize all the generic links"""
@@ -90,10 +78,7 @@ def completetemplatevars(templatevars, session, bannerheight=135):
     templatevars["baseurl"] = getattr(session.instance, "baseurl", "/")
     if not templatevars["baseurl"].endswith("/"):
     	templatevars["baseurl"] += "/"
-  banner_layout = layout_banner(bannerheight, session)
-  banner_layout["logo_alttext"] = session.localize("Pootle Logo")
-  banner_layout["banner_alttext"] = session.localize("WordForge Translation Project")
-  templatevars.update(banner_layout)
+  templatevars["logo_alttext"] = session.localize("Pootle Logo")
   templatevars["aboutlink"] = session.localize("About this Pootle server")
   templatevars["uilanguage"] = weblanguage(session.language)
   templatevars["uidir"] = languagedir(session.language)
@@ -140,11 +125,11 @@ class PootleNavPage(PootlePage):
     links = {"admin": None, "project": [], "language": [], "goal": [], "pathlinks": []}
     if currentfolder:
       pathlinks = []
-      dirs = currentfolder.split("/")
+      dirs = currentfolder.split(os.path.sep)
       if dirfilter is None:
         dirfilter = currentfolder
       
-      depth = dirfilter.count('/') + 1
+      depth = dirfilter.count(os.path.sep) + 1
       if dirfilter == "":
         depth -= 1
       elif dirfilter.endswith(".po") or dirfilter.endswith(".xlf"):
@@ -223,12 +208,12 @@ class PootleNavPage(PootlePage):
     """returns a sentence summarizing item statistics"""
     translated = projectstats.get("translated", [])
     total = projectstats.get("total", [])
-    if "translatedwords" in projectstats:
-      translatedwords = projectstats["translatedwords"]
+    if "translatedsourcewords" in projectstats:
+      translatedwords = projectstats["translatedsourcewords"]
     else:
       translatedwords = project.countwords(translated)
-    if "totalwords" in projectstats:
-      totalwords = projectstats["totalwords"]
+    if "totalsourcewords" in projectstats:
+      totalwords = projectstats["totalsourcewords"]
     else:
       totalwords = project.countwords(total)
     if isinstance(translated, list):
@@ -266,14 +251,14 @@ class PootleNavPage(PootlePage):
                 "graph": self.localize("Graph")}
     return headings
 
-  def getstats(self, project, projectstats, numfiles):
+  def getstats(self, project, projectstats):
     """returns a list with the data items to fill a statistics table
     Remember to update getstatsheadings() above as needed"""
-    wanted = ["translated", "fuzzy", "untranslated", "total"]
+    wanted = ["translated", "fuzzy", "total"]
     gotten = {}
     for key in wanted:
       gotten[key] = projectstats.get(key, [])
-      wordkey = key + "words"
+      wordkey = key + "sourcewords"
       if wordkey in projectstats:
         gotten[wordkey] = projectstats[wordkey]
       else:
@@ -284,12 +269,13 @@ class PootleNavPage(PootlePage):
         gotten[key] = len(gotten[key])
 
     gotten["untranslated"] = gotten["total"] - gotten["translated"] - gotten["fuzzy"]
-    gotten["untranslatedwords"] = gotten["totalwords"] - gotten["translatedwords"] - gotten["fuzzywords"]
+    gotten["untranslatedsourcewords"] = gotten["totalsourcewords"] - gotten["translatedsourcewords"] - gotten["fuzzysourcewords"]
 
-    for key in wanted[:-1]:
+    wanted = ["translated", "fuzzy", "untranslated"]
+    for key in wanted:
       percentkey = key + "percentage"
-      wordkey = key + "words"
-      gotten[percentkey] = gotten[wordkey]*100/max(gotten["totalwords"], 1)
+      wordkey = key + "sourcewords"
+      gotten[percentkey] = gotten[wordkey]*100/max(gotten["totalsourcewords"], 1)
 
     for key in gotten:
       if key.find("check-") == 0:
