@@ -42,7 +42,10 @@ from translate.misc import optrecurse
 from Pootle import __version__ as pootleversion
 from translate import __version__ as toolkitversion
 from jToolkit import __version__ as jtoolkitversion
-from elementtree import ElementTree
+try:
+  from xml.etree import ElementTree
+except ImportError:
+  from elementtree import ElementTree
 # We don't need kid in this file, but this will show quickly if it is not 
 # installed. jToolkit won't complain, so we have to stop here if we don't have kid
 import kid
@@ -134,8 +137,8 @@ class PootleServer(users.OptionalLoginAppServer, templateserver.TemplateServer):
       try:
         self.translation = self.potree.getproject(self.defaultlanguage, 'pootle')
         return
-      except:
-        self.errorhandler.logerror("Could not initialize translation")
+      except Exception, e:
+        self.errorhandler.logerror("Could not initialize translation:\n%s" % str(e))
     # if no translation available, set up a blank translation
     super(PootleServer, self).inittranslation()
     # the inherited method overwrites self.languagenames, so we have to redo it
@@ -148,9 +151,9 @@ class PootleServer(users.OptionalLoginAppServer, templateserver.TemplateServer):
     else:
       try:
         return self.potree.getproject(language, 'pootle')
-      except:
+      except Exception, e:
         if not language.startswith('en'):
-          self.errorhandler.logerror("Could not get translation for language %r" % language)
+          self.errorhandler.logerror("Could not get translation for language %r:\n%s" % (language,str(e)))
         return self.translation
 
   def refreshstats(self, args):
@@ -159,8 +162,8 @@ class PootleServer(users.OptionalLoginAppServer, templateserver.TemplateServer):
       def filtererrorhandler(functionname, str1, str2, e):
         print "error in filter %s: %r, %r, %s" % (functionname, str1, str2, e)
         return False
-      checkerclasses = [projects.checks.StandardChecker, projects.pofilter.StandardPOChecker]
-      stdchecker = projects.pofilter.POTeeChecker(checkerclasses=checkerclasses, errorhandler=filtererrorhandler)
+      checkerclasses = [projects.checks.StandardChecker, projects.checks.StandardUnitChecker]
+      stdchecker = projects.checks.TeeChecker(checkerclasses=checkerclasses, errorhandler=filtererrorhandler)
       for arg in args:
         if not os.path.exists(arg):
           print "file not found:", arg
@@ -464,7 +467,7 @@ class PootleServer(users.OptionalLoginAppServer, templateserver.TemplateServer):
             encoding = getattr(pofile, "encoding", "UTF-8")
             page.content_type = "text/plain; charset=%s" % encoding
             return page
-        elif bottom.endswith(".csv") or bottom.endswith(".xlf") or bottom.endswith(".ts") or bottom.endswith("po") or bottom.endswith("mo"):
+        elif bottom.endswith(".csv") or bottom.endswith(".xlf") or bottom.endswith(".ts") or bottom.endswith(".po") or bottom.endswith(".mo"):
           destfilename = os.path.join(*pathwords)
           basename, extension = os.path.splitext(destfilename)
           pofilename = basename + os.extsep + project.fileext
@@ -535,13 +538,13 @@ class PootleOptionParser(simplewebserver.WebOptionParser):
       import psyco
       self.add_option('', "--psyco", dest="psyco", default=None, choices=psycomodes, metavar="MODE",
                       help="use psyco to speed up the operation, modes: %s" % (", ".join(psycomodes)))
-    except:
+    except ImportError, e:
       return
 
 def checkversions():
   """Checks that version dependencies are met"""
-  if not hasattr(toolkitversion, "build") or toolkitversion.build < 10000:
-    raise RuntimeError("requires Translate Toolkit version >= 1.0.  Current installed version is: %s" % toolkitversion.ver)
+  if not hasattr(toolkitversion, "build") or toolkitversion.build < 11000:
+    raise RuntimeError("requires Translate Toolkit version >= 1.1.  Current installed version is: %s" % toolkitversion.ver)
 
 def usepsyco(options):
   # options.psyco == None means the default, which is "full", but don't give a warning...
