@@ -408,7 +408,7 @@ class pootlefile(Wrapper):
       newpo.msgidcomments.append('"_: suggested by %s\\n"' % username)
     newpo.target = suggtarget
     newpo.markfuzzy(False)
-    self.pendingfile.units.append(newpo)
+    self.pendingfile.addunit(newpo)
     self.savependingfile()
     self.statistics.reclassifyunit(item)
 
@@ -575,13 +575,14 @@ class pootlefile(Wrapper):
         matches.append((oldpo, None))
     return matches
 
-  def mergeitem(self, oldpo, newpo, username):
+  def mergeitem(self, oldpo, newpo, username, suggest=False):
     """merges any changes from newpo into oldpo"""
     unchanged = oldpo.target == newpo.target
-#    if oldpo.isblankmsgstr() or newpo.isblankmsgstr() or oldpo.isheader() or newpo.isheader() or unchanged:
-    if not oldpo.target or not newpo.target or oldpo.isheader() or newpo.isheader() or unchanged:
+
+    if not suggest and (not oldpo.target or not newpo.target or oldpo.isheader() or newpo.isheader() or unchanged):
       oldpo.merge(newpo)
-    else:
+    elif not unchanged:
+      #XXX: this is very inefficient!
       for item, matchpo in enumerate(self.transunits):
         if matchpo == oldpo:
           strings = getattr(newpo.target, "strings", [newpo.target])
@@ -589,17 +590,22 @@ class pootlefile(Wrapper):
           return
       raise KeyError("Could not find item for merge")
 
-  def mergefile(self, newfile, username, allownewstrings=True):
+  def mergefile(self, newfile, username, allownewstrings=True, suggestions=False):
     """make sure each msgid is unique ; merge comments etc from duplicates into original"""
     self.makeindex()
     matches = self.matchitems(newfile)
     for oldpo, newpo in matches:
+      if suggestions:
+        if oldpo and newpo:
+            self.mergeitem(oldpo, newpo, username, suggest=True)
+        continue
+
       if oldpo is None:
         if allownewstrings:
           if isinstance(newpo, po.pounit):
-            self.units.append(newpo)
+            self.addunit(newpo)
           else:
-            self.units.append(self.UnitClass.buildfromunit(newpo))
+            self.addunit(self.UnitClass.buildfromunit(newpo))
       elif newpo is None:
         # TODO: mark the old one as obsolete
         pass
@@ -609,7 +615,7 @@ class pootlefile(Wrapper):
         if hasattr(newpo, "sourcecomments"):
           oldpo.sourcecomments = newpo.sourcecomments
 
-    if not isinstance(newfile, po.pofile):
+    if not isinstance(newfile, po.pofile) or suggestions:
       #TODO: We don't support updating the header yet.
       self.savepofile()
       # the easiest way to recalculate everything
@@ -639,7 +645,7 @@ class pootlefile(Wrapper):
       header = self.UnitClass("", encoding=self.encoding)
       header.target = ""
     if header:
-      header.initallcomments(blankall=True)
+      header._initallcomments(blankall=True)
       if newheader:
         for i in range(len(header.allcomments)):
           header.allcomments[i].extend(newheader.allcomments[i])
@@ -648,22 +654,6 @@ class pootlefile(Wrapper):
     # the easiest way to recalculate everything
     self.readpofile()
 
-  def getfilename(self, path=None):
-    """Checks for and returns filename or path of pootlefile"""
-    if not os.path.exists(self.filename):
-      return None
-    if path:
-      return self.filename
-    else:
-      return self.filename.split("/")[-1]
-
-  def getext(self):
-    """Returns the extension of the pootlefile"""
-    if not os.path.exists(self.filename):
-      return None
-    else:
-      return os.path.splitext(self.filename)[1]
-
 class Search:
   """an object containing all the searching information"""
   def __init__(self, dirfilter=None, matchnames=[], assignedto=None, assignedaction=None, searchtext=None):
