@@ -26,10 +26,10 @@ from Pootle import pootlefile
 from Pootle import pagelayout
 from translate.misc import autoencode
 import os
-import sre
+import re
 
-languagere = sre.compile("^[a-z]{2,3}([_-][A-Z]{2,3}|)$")
-regionre = sre.compile("^[_-][A-Z]{2,3}$")
+languagere = re.compile("^[a-z]{2,3}([_-][A-Z]{2,3}|)$")
+regionre = re.compile("^[_-][A-Z]{2,3}$")
 
 class POTree:
   """Manages the tree of projects and languages"""
@@ -40,6 +40,7 @@ class POTree:
       self.saveprefs()
     self.projects = instance.projects
     self.podirectory = instance.podirectory
+    self.instance = instance
     self.projectcache = {}
 
   def saveprefs(self):
@@ -147,6 +148,12 @@ class POTree:
           projectcheckerstyle = self.getprojectcheckerstyle(projectcode)
           if projectcheckerstyle != value:
             self.setprojectcheckerstyle(projectcode, value)
+      elif key.startswith("projectfiletype-"):
+        projectcode = key.replace("projectfiletype-", "", 1)
+        if hasattr(self.projects, projectcode):
+          projectlocalfiletype = self.getprojectlocalfiletype(projectcode)
+          if projectlocalfiletype != value:
+            self.setprojectlocalfiletype(projectcode, value)
       elif key.startswith("projectcreatemofiles-"):
         projectcode = key.replace("projectcreatemofiles-", "", 1)
         if hasattr(self.projects, projectcode):
@@ -160,10 +167,12 @@ class POTree:
         if hasattr(self.projects, projectcode):
           raise ValueError("Already have project with the code %s" % projectcode)
         projectname = argdict.get("newprojectname", projectcode)
+        projecttype = argdict.get("newprojectfiletype", "")
         projectdescription = argdict.get("newprojectdescription", "")
         projectcheckerstyle = argdict.get("newprojectcheckerstyle", "")
         projectcreatemofiles = argdict.get("newprojectcreatemofiles", "")
         setattr(self.projects, projectcode + ".fullname", projectname)
+        setattr(self.projects, projectcode + ".localfiletype", projecttype)
         setattr(self.projects, projectcode + ".description", projectdescription)
         setattr(self.projects, projectcode + ".checkerstyle", projectcheckerstyle)
         setattr(self.projects, projectcode + ".createmofiles", projectcreatemofiles)
@@ -333,6 +342,20 @@ class POTree:
     projectprefs = getattr(self.projects, projectcode)
     setattr(projectprefs, "description", projectdescription)
 
+  def getprojectlocalfiletype(self, projectcode):
+    """returns the project allowed file type. We assume it is .po if nothing
+    else is specified."""
+    projectprefs = getattr(self.projects, projectcode)
+    type = getattr(projectprefs, "localfiletype", "po")
+    if not type:
+      type = "po"
+    return type
+
+  def setprojectlocalfiletype(self, projectcode, projectfiletype):
+    """sets the allowed file type for the project"""
+    projectprefs = getattr(self.projects, projectcode)
+    setattr(projectprefs, "localfiletype", projectfiletype)
+
   def getprojectcheckerstyle(self, projectcode):
     """returns the project checker style"""
     projectprefs = getattr(self.projects, projectcode)
@@ -355,6 +378,25 @@ class POTree:
 
   def hasgnufiles(self, podir, languagecode=None, depth=0, maxdepth=3, poext="po"):
     """returns whether this directory contains gnu-style PO filenames for the given language"""
+    try:
+      if (podir.startswith(self.podirectory)):
+        def getprojectcode(podir=podir):
+          """Get the projectcode using the supplied podir."""
+          dirs = podir[len(self.podirectory):].split(os.sep)
+          if len(dirs[0]):
+            projectcode = dirs[0]
+          else:
+            projectcode = dirs[1]
+          return projectcode
+        projectprefs = getattr(self.projects, getprojectcode())
+        style = getattr(projectprefs, "treestyle")
+        if    style == "gnu"    \
+           or style == "nongnu":
+          return style
+        else:
+          print "Unsupported treestyle value (project %s): %s"%(projectcode,style)
+    except:
+      pass
     #Let's check to see if we specifically find the correct gnu file
     foundgnufile = False
     if not os.path.isdir(podir):
@@ -415,7 +457,6 @@ class POTree:
     projectdir = os.path.join(self.podirectory, projectcode)
     if not os.path.exists(projectdir):
       raise IndexError("directory not found for project %s" % (projectcode))
-      return None
     languagedir = os.path.join(projectdir, languagecode)
     if not os.path.exists(languagedir):
       languagedirs = [languagedir for languagedir in os.listdir(projectdir) if self.languagematch(languagecode, languagedir)]
@@ -439,13 +480,23 @@ class POTree:
 
   def getpofiles(self, languagecode, projectcode, poext="po"):
     """returns a list of po files for the project and language"""
+
     def addfiles(podir, dirname, fnames):
       """adds the files to the set of files for this project"""
       basedirname = dirname.replace(podir, "", 1)
       while basedirname.startswith(os.sep):
         basedirname = basedirname.replace(os.sep, "", 1)
-      ponames = [fname for fname in fnames if fname.endswith(os.extsep+poext)]
+      ponames = []
+      for fname in fnames:
+        #check that it actually exists (to avoid problems with broken symbolic 
+        # links, for example)
+        if not os.path.exists(os.path.join(dirname, fname)):
+          print "file does not exist:", os.path.join(dirname, fname)
+          continue
+        if fname.endswith(os.extsep+poext):
+          ponames.append(fname)
       pofilenames.extend([os.path.join(basedirname, poname) for poname in ponames])
+
     def addgnufiles(podir, dirname, fnames):
       """adds the files to the set of files for this project"""
       basedirname = dirname.replace(podir, "", 1)
@@ -454,6 +505,7 @@ class POTree:
       ext = os.extsep + poext
       ponames = [fn for fn in fnames if fn.endswith(ext) and self.languagematch(languagecode, fn[:-len(ext)])]
       pofilenames.extend([os.path.join(basedirname, poname) for poname in ponames])
+
     pofilenames = []
     podir = self.getpodir(languagecode, projectcode)
     if self.hasgnufiles(podir, languagecode) == "gnu":
@@ -462,6 +514,10 @@ class POTree:
       os.path.walk(podir, addfiles, podir)
     return pofilenames
 
+  def getdefaultrights(self):
+    """Returns the default rights for a logged in user on this Pootle server."""
+    return getattr(self.instance, "defaultrights", "view, suggest, archive, pocompile")
+
   def refreshstats(self):
     """manually refreshes (all or missing) the stats files"""
     for projectcode in self.getprojectcodes():
