@@ -23,7 +23,6 @@
 
 from translate.storage import factory
 from translate.filters import checks
-from translate.filters import pofilter
 from translate.convert import po2csv
 from translate.convert import po2xliff
 from translate.convert import xliff2po
@@ -33,9 +32,10 @@ from translate.convert import po2oo
 from translate.tools import pocompile
 from translate.tools import pogrep
 from translate.search import match
+from translate.search import indexer
 from Pootle import statistics
 from Pootle import pootlefile
-from Pootle import versioncontrol
+from translate.storage import versioncontrol
 from jToolkit import timecache
 from jToolkit import prefs
 import time
@@ -43,7 +43,6 @@ import os
 import cStringIO
 import traceback
 import gettext
-from jToolkit.data import indexer
 
 class RightsError(ValueError):
   pass
@@ -96,8 +95,8 @@ class TranslationProject(object):
     self.projectdescription = self.potree.getprojectdescription(self.projectcode)
     self.pofiles = potimecache(15*60, self)
     self.projectcheckerstyle = self.potree.getprojectcheckerstyle(self.projectcode)
-    checkerclasses = [checks.projectcheckers.get(self.projectcheckerstyle, checks.StandardChecker), pofilter.StandardPOChecker]
-    self.checker = pofilter.POTeeChecker(checkerclasses=checkerclasses, errorhandler=self.filtererrorhandler, languagecode=languagecode)
+    checkerclasses = [checks.projectcheckers.get(self.projectcheckerstyle, checks.StandardChecker), checks.StandardUnitChecker]
+    self.checker = checks.TeeChecker(checkerclasses=checkerclasses, errorhandler=self.filtererrorhandler, languagecode=languagecode)
     self.fileext = self.potree.getprojectlocalfiletype(self.projectcode)
     self.quickstats = {}
     # terminology matcher
@@ -501,6 +500,8 @@ class TranslationProject(object):
         origpofile.mergefile(newfile, session.username)
       elif "translate" in rights:
         origpofile.mergefile(newfile, session.username, allownewstrings=False)
+      elif "suggest" in rights:
+        origpofile.mergefile(newfile, session.username, suggestions=True)
       else:
         raise RightsError(session.localize("You do not have rights to upload files here"))
     else:
@@ -589,7 +590,7 @@ class TranslationProject(object):
     if "commit" not in self.getrights(session):
       raise RightsError(session.localize("You do not have rights to commit files here"))
     pathname = self.getuploadpath(dirname, pofilename)
-    stats = self.getquickstats([pofilename])
+    stats = self.getquickstats([os.path.join(dirname, pofilename)])
     statsstring = "%d of %d messages translated (%d fuzzy)." % \
         (stats["translated"], stats["total"], stats["fuzzy"])
     versioncontrol.commitfile(pathname, message="Commit from %s by user %s. %s" % 
@@ -632,8 +633,10 @@ class TranslationProject(object):
       else:
         origpofile = None
       pot2po.convertpot(inputfile, outputfile, origpofile)
-      dirname, potfilename = os.path.dirname(potfilename), os.path.basename(potfilename)
-      self.uploadfile(session, dirname, pofilename, outputfile.getvalue())
+      outfile = open(origpofilename, "wb")
+      outfile.write(outputfile.getvalue())
+      outfile.close()
+      self.scanpofiles()
 
   def filtererrorhandler(self, functionname, str1, str2, e):
     print "error in filter %s: %r, %r, %s" % (functionname, str1, str2, e)
@@ -645,7 +648,9 @@ class TranslationProject(object):
     try:
       # using zip command line is fast
       os.system("cd %s ; zip -r - %s > %s" % (self.podir, " ".join(pofilenames), tempzipfile))
-      return open(tempzipfile, "r").read()
+      filedata = open(tempzipfile, "r").read()
+      if filedata:
+        return filedata
     finally:
       if os.path.exists(tempzipfile):
         os.remove(tempzipfile)
@@ -813,6 +818,7 @@ class TranslationProject(object):
 
   def matchessearch(self, pofilename, search):
     """returns whether any items in the pofilename match the search (based on collected stats etc)"""
+    # wrong file location in a "dirfilter" search?
     if search.dirfilter is not None and not pofilename.startswith(search.dirfilter):
       return False
     # search.assignedto == [None] means assigned to nobody
@@ -900,7 +906,7 @@ class TranslationProject(object):
         # TODO: move this to iteritems
         if search.searchtext:
           unit = pofile.transunits[item]
-          if grepfilter.filterelement(unit):
+          if grepfilter.filterunit(unit):
             yield pofilename, item
         else:
           yield pofilename, item
@@ -941,7 +947,7 @@ class TranslationProject(object):
         if search.searchtext:
           validitem = False
           unit = pofile.transunits[item]
-          if grepfilter.filterelement(unit):
+          if grepfilter.filterunit(unit):
             validitem = True
           if not validitem:
             continue
@@ -967,7 +973,7 @@ class TranslationProject(object):
         # TODO: move this to iteritems
         if search.searchtext:
           unit = pofile.transunits[item]
-          if grepfilter.filterelement(unit):
+          if grepfilter.filterunit(unit):
             pofile.assigns.unassign(item, assignedto, action)
             assigncount += 1
         else:
@@ -975,10 +981,11 @@ class TranslationProject(object):
           assigncount += 1
     return assigncount
 
-  def updatequickstats(self, pofilename, translatedwords, translated, fuzzywords, fuzzy, totalwords, total):
+  def updatequickstats(self, pofilename, translatedwords, translated, fuzzywords, fuzzy, totalwords, total, save=True):
     """updates the quick stats on the given file"""
     self.quickstats[pofilename] = (translatedwords, translated, fuzzywords, fuzzy, totalwords, total)
-    self.savequickstats()
+    if save:
+      self.savequickstats()
 
   def savequickstats(self):
     """saves the quickstats"""
@@ -1027,7 +1034,8 @@ class TranslationProject(object):
       alltotalwords += totalwords
       alltotal += total
     for pofilename in slowfiles:
-      self.pofiles[pofilename].statistics.updatequickstats()
+      self.pofiles[pofilename].statistics.updatequickstats(save=False)
+      self.savequickstats()
       translatedwords, translated, fuzzywords, fuzzy, totalwords, total = self.quickstats[pofilename]
       alltranslatedwords += translatedwords
       alltranslated += translated
@@ -1035,9 +1043,9 @@ class TranslationProject(object):
       allfuzzy += fuzzy
       alltotalwords += totalwords
       alltotal += total
-    return {"translatedwords": alltranslatedwords, "translated": alltranslated, 
-            "fuzzywords": allfuzzywords, "fuzzy": allfuzzy, 
-            "totalwords": alltotalwords, "total": alltotal}
+    return {"translatedsourcewords": alltranslatedwords, "translated": alltranslated, 
+            "fuzzysourcewords": allfuzzywords, "fuzzy": allfuzzy, 
+            "totalsourcewords": alltotalwords, "total": alltotal}
 
   def combinestats(self, pofilenames=None):
     """combines translation statistics for the given po files (or all if None given)"""
@@ -1276,7 +1284,7 @@ class TranslationProject(object):
     converterclass = converters.get(destformat, None)
     if converterclass is None:
       raise ValueError("No converter available for %s" % destfilename)
-    contents = converterclass().convertfile(pofile)
+    contents = converterclass().convertstore(pofile)
     if not isinstance(contents, basestring):
       contents = str(contents)
     try:
@@ -1299,7 +1307,7 @@ class TranslationProject(object):
       elif not hasattr(pofile, "sourceindex"):
         pofile.makeindex()
       unit = pofile.sourceindex.get(message, None)
-      if not unit or unit.isblankmsgstr():
+      if not unit or not unit.istranslated():
         continue
       tmsg = unit.target
       if tmsg is not None:
@@ -1316,7 +1324,7 @@ class TranslationProject(object):
         elif not hasattr(pofile, "sourceindex"):
           pofile.makeindex()
         unit = pofile.sourceindex.get(message, None)
-        if not unit or unit.isblankmsgstr() or unit.isfuzzy():
+        if not unit or not unit.istranslated():
           continue
         tmsg = unit.target
         if tmsg is not None:
@@ -1341,7 +1349,7 @@ class TranslationProject(object):
         if pluralequation:
           pluralfn = gettext.c2py(pluralequation)
           unit = pofile.sourceindex.get(singular, None)
-          if not unit or unit.isblankmsgstr() or unit.isfuzzy():
+          if not unit or not unit.istranslated():
             continue
           tmsg = unit.target.strings[pluralfn(n)]
           if tmsg is not None:
@@ -1366,7 +1374,7 @@ class DummyProject(TranslationProject):
     """initializes the project with the given podir"""
     self.podir = podir
     if checker is None:
-      self.checker = pofilter.POTeeChecker()
+      self.checker = checks.TeeChecker()
     else:
       self.checker = checker
     self.projectcode = projectcode
