@@ -188,6 +188,30 @@ class ServerTester:
 #                pocontents_download = self.fetch_page("zxx/testproject/test_upload.po")
 #                assert pocontents_download == pocontents_expected
 
+    def test_upload_suggestions(self):
+        """tests that we can upload when we only have suggest rights"""
+        self.login()
+        podir = self.setup_testproject_dir(perms="view, suggest")
+
+        tree = potree.POTree(self.prefs.Pootle)
+        project = projects.TranslationProject("zxx", "testproject", tree)
+        po1contents = '#: test.c\nmsgid "test"\nmsgstr ""\n'
+        open(os.path.join(podir, "test_upload.po"), "w").write(po1contents)
+
+        fields = [("doupload", "Upload File")]
+        pocontents = '#: test.c\nmsgid "test"\nmsgstr "rest"\n'
+        files = [("uploadfile", "test_upload.po", pocontents)]
+        content_type, upload_contents = postMultipart.encode_multipart_formdata(fields, files)
+        headers = {"Content-Type": content_type, "Content-Length": len(upload_contents)}
+        response = self.post_request("zxx/testproject/", upload_contents, headers)
+        assert ' href="test_upload.po?' in response
+        # Check that the orignal file didn't take the new suggestion.
+        # We test with 'in' since the header is added
+        assert po1contents in self.fetch_page("zxx/testproject/test_upload.po")
+        suggestions_content = open(os.path.join(podir, "test_upload.po.pending"), 'r').read()
+        assert 'msgstr "rest"' in suggestions_content
+    test_upload_suggestions.userprefs = {"rights.siteadmin": False}
+
     def test_upload_overwrite(self):
         """tests that we can overwrite a file in a project"""
         self.login()
@@ -381,7 +405,7 @@ class ServerTester:
 
         # Fetch the page and check that the fuzzy checkbox is NOT checked.
         translatepage = self.fetch_page("zxx/testproject/test_fuzzy.po?translate=1&editing=1")
-        assert '<input disabled="False" accesskey="f" type="checkbox" name="fuzzy0" />' in translatepage
+        assert '<input accesskey="f" type="checkbox" name="fuzzy0" />' in translatepage
 
         fields = {"orig-pure0.0": "fuzzy", "trans0": "wuzzy", "submit0": "submit", "fuzzy0": "on", "pofilename": "test_fuzzy.po"}
         content_type, post_contents = postMultipart.encode_multipart_formdata(fields.items(), [])
@@ -390,7 +414,7 @@ class ServerTester:
 
         # Fetch the page again and check that the fuzzy checkbox IS checked.
         translatepage = self.fetch_page("zxx/testproject/test_fuzzy.po?translate=1&editing=1")
-        assert '<input disabled="False" type="checkbox" accesskey="f" checked="checked" name="fuzzy0" />' in translatepage
+        assert '<input type="checkbox" accesskey="f" checked="checked" name="fuzzy0" />' in translatepage
 
         tree = potree.POTree(self.prefs.Pootle)
         project = projects.TranslationProject("zxx", "testproject", tree)
@@ -406,7 +430,7 @@ class ServerTester:
 
         # Fetch the page once more and check that the fuzzy checkbox is NOT checked.
         translatepage = self.fetch_page("zxx/testproject/test_fuzzy.po?translate=1&editing=1")
-        assert '<input disabled="False" accesskey="f" type="checkbox" name="fuzzy0" />' in translatepage
+        assert '<input accesskey="f" type="checkbox" name="fuzzy0" />' in translatepage
         tree = potree.POTree(self.prefs.Pootle)
         project = projects.TranslationProject("zxx", "testproject", tree)
         pofile = project.getpofile("test_fuzzy.po")
