@@ -5,12 +5,12 @@ from Pootle import pootle
 from Pootle import projects
 from translate.storage import po
 from translate.storage import test_po
-from translate.filters import pofilter
+from translate.filters import checks
 from translate.misc import wStringIO
 
 import os
 
-class TestPootleFile(test_po.TestPO):
+class TestPootleFile(test_po.TestPOFile):
     class pootletestfile(pootlefile.pootlefile):
         def __init__(self):
             """wrapper constructor for pootlefile that uses temporary filename"""
@@ -65,8 +65,8 @@ msgstr ""'''
             print "error in filter %s: %r, %r, %s" % (functionname, str1, str2, e)
             return False
 
-        checkerclasses = [projects.checks.StandardChecker, projects.pofilter.StandardPOChecker]
-        stdchecker = projects.pofilter.POTeeChecker(checkerclasses=checkerclasses, errorhandler=filtererrorhandler)
+        checkerclasses = [checks.StandardChecker, checks.StandardUnitChecker]
+        stdchecker = checks.TeeChecker(checkerclasses=checkerclasses, errorhandler=filtererrorhandler)
         dummyproject = projects.DummyStatsProject(self.rundir, stdchecker, "unittest_project", "xx")
 
         pofile = pootlefile.pootlefile(dummyproject, "test.po", generatestats=False)
@@ -87,20 +87,11 @@ msgstr ""'''
         assert unit.source == "test"
         assert unit.target == "rest"
 
-    def test_filename(self):
-        """checks and tests the filename API"""
-        posource = '#: test.c\nmsgid "hidden"\nmsgstr "hisomu"\n'
-        w = open('test.po', 'w')
-        w.write(posource)
-        pofile = self.poparse(posource)
-        assert pofile.getfilename(path=True) == pofile.filename
-        assert pofile.getext() == ".po"
-
     def test_classify(self):
         """Test basic classification"""
         posource = 'msgid "test"\nmsgstr ""\n'
         pofile = self.poparse(posource)
-        pofile.project.checker = pofilter.POTeeChecker()
+        pofile.project.checker = checks.TeeChecker()
         unit = pofile.units[0]
         classify = pofile.statistics.classifyunit
         classes = classify(unit)
@@ -135,11 +126,6 @@ msgstr ""'''
         assert classify['fuzzy'] == [1]
         assert classify['blank'] == [2]
         assert len(classify['total']) == 3
-        #cleanup remaining files
-        #commented while locking code is removed:
-        #os.remove("test.po.lock")
-        os.remove("test.po")
-        os.remove("test.po.pending")
 
     def test_updateunit(self):
         """Test the updateunit() method."""
